@@ -5,7 +5,7 @@ from time import sleep
 
 import pytest
 
-from cloudpathlib import DirectoryNotEmpty
+from cloudpathlib.exceptions import CloudPathIsADirectoryError, DirectoryNotEmptyError
 
 
 def test_file_discovery(rig):
@@ -23,10 +23,10 @@ def test_file_discovery(rig):
     assert len(list(p3.iterdir())) == 3
     assert len(list(p3.glob("**/*"))) == 3
 
-    with pytest.raises(ValueError):
+    with pytest.raises(CloudPathIsADirectoryError):
         p3.unlink()
 
-    with pytest.raises(DirectoryNotEmpty):
+    with pytest.raises(DirectoryNotEmptyError):
         p3.rmdir()
     p3.rmtree()
     assert not p3.exists()
@@ -96,6 +96,14 @@ def test_file_read_writes(rig, tmp_path):
     assert cloud_rel_paths == dled_rel_paths
 
 
+def test_cloud_path_download_to(rig, tmp_path):
+    p = rig.create_cloud_path("dir_0/file0_0.txt")
+    dl_dir = tmp_path
+    assert not (dl_dir / p.name).exists()
+    p.download_to(dl_dir)
+    assert (dl_dir / p.name).is_file()
+
+
 def test_fspath(rig):
     p = rig.create_cloud_path("dir_0")
     assert os.fspath(p) == p.fspath
